@@ -8,7 +8,7 @@ from enum import Enum
 
 import numpy as np
 
-from ctypes import c_int, c_void_p, c_char_p, c_long, c_bool, cdll, sizeof
+from ctypes import c_int, c_uint, c_void_p, c_char_p, c_long, c_bool, cdll, sizeof
 from numpy.ctypeslib import as_ctypes
 
 supported_games_dict = {
@@ -18,6 +18,7 @@ supported_games_dict = {
 
 DLL32 = "DLL/32Bit/"
 DLL64 = "DLL/64Bit/"
+DATA_PATH = "/data/"
 
 def _load_cdll(path, name):
     relPath = ""
@@ -102,6 +103,15 @@ amle_lib.getScreenWidth.restype = c_int
 amle_lib.getScreenHeight.argtypes = [c_void_p]
 amle_lib.getScreenHeight.restype = c_int
 
+amle_lib.setEmulatorSpeed.argtypes = [c_void_p, c_int]
+amle_lib.setEmulatorSpeed.restype = None
+
+amle_lib.pokeMemory.argtypes = [c_void_p, c_uint, c_int]
+amle_lib.pokeMemory.restype = c_bool
+
+amle_lib.toggleSound.argtypes = [c_void_p, c_bool]
+amle_lib.toggleSound.restype = None
+
 amle_lib.step.argtypes = [c_void_p]
 amle_lib.step.restype = None
 
@@ -115,7 +125,7 @@ def _str_as_bytes(arg):
 class AmLEInterface(object):
 
     def __init__(self):
-        path = _str_as_bytes(os.path.dirname(os.path.realpath(__file__)) + "/data")
+        path = _str_as_bytes(os.path.dirname(os.path.realpath(__file__)) + DATA_PATH)
         self.obj = amle_lib.AmLE_new(path)
 
     def loadROM(self, game, path):
@@ -165,6 +175,15 @@ class AmLEInterface(object):
     
     def getScreenHeight(self):
         return amle_lib.getScreenHeight(self.obj)
+    
+    def setEmulatorSpeed(self, speed):
+        amle_lib.setEmulatorSpeed(self.obj, speed)
+        
+    def pokeMemory(self, addr, value):
+        amle_lib.pokeMemory(self.obj, addr, value)
+        
+    def toggleSound(self, value):
+        amle_lib.toggleSound(self.obj, value)
 
     def step(self):
         amle_lib.step(self.obj)
